@@ -19,3 +19,22 @@ sub scrape {
 }
 
 1;
+__END__
+
+=head1 NAME
+
+WWW::MobileCarrierJP::DoCoMo::CIDR - get CIDR informtation from DoCoMo site.
+
+=head1 SYNOPSIS
+
+    use WWW::MobileCarrierJP::DoCoMo::CIDR;
+    WWW::MobileCarrierJP::DoCoMo::CIDR->scrape();
+
+=head1 AUTHOR
+
+Tokuhiro Matsuno < tokuhirom gmail com >
+
+=head1 SEE ALSO
+
+L<WWW::MobileCarrierJP>
+
